@@ -425,7 +425,7 @@ class Base(Controller):
                 "action" : "store"
             }),
             (['-c','--columns'],{
-                "help" : "Whether column names are present",
+                "help" : "Whether column names are NOT present",
                 "action" : "store_true"
             }),
             (['--csv'],{
@@ -446,7 +446,7 @@ class Base(Controller):
         from ..ext.faker import generate_fake_data
         n_lines = int(self.app.pargs.__dict__.get('n') or 10)
         template = self.app.pargs.__dict__.get('t') or self.app.pargs.__dict__.get('template')
-        columns = self.app.pargs.__dict__.get('c') or self.app.pargs.__dict__.get('columns')
+        columns = not (self.app.pargs.__dict__.get('c') or self.app.pargs.__dict__.get('columns')) 
         csv = self.app.pargs.__dict__.get('csv')
         primary_key = self.app.pargs.__dict__.get('pk') or self.app.pargs.__dict__.get('primary_key')
         delimiter = self.app.pargs.__dict__.get('d') or ','
