@@ -69,16 +69,16 @@ def get_oauth_token(config):
 
 
 def get_client(oauth=False):
-    if not oauth:
-        with open(os.path.expanduser('~/.dt_config.json')) as f:
-            config = json.load(f)
-            api_key = config['asana_api_key']
-            
+    with open(os.path.expanduser('~/.dt_config.json')) as f:
+        config = json.load(f)
+    
+    # check if asana api key exists
+    if 'asana_api_key' in config.keys():
+        api_key = config['asana_api_key']
+        
         # create asana client
         client = asana.Client.access_token(api_key)
     else:
-        with open(os.path.expanduser('~/.dt_config.json')) as f:
-            config = json.load(f)
         
         try:
             client = asana.Client.access_token(config['asana_token']['access_token'])
